@@ -8,7 +8,7 @@ def set_infinite_scroll(context):
     """ renders the html to set up and load the necessary JS and CSS.
     This is used by {% set_infinite_scroll %} tag.
     """
-    data = context.dicts[-1]
+    data = get_context_data(context)
     return render_to_string('infscroll/scroll.html', data)
 
 @register.simple_tag(name='infinite_scroll_box', takes_context=True)
@@ -16,7 +16,7 @@ def infinite_scroll_box(context):
     """ renders the html that loads the dynamic content.
     This is used by {% infinite_scroll_box %} tag.
     """
-    data = context.dicts[-1]
+    data = get_context_data(context)
     return render_to_string('infscroll/scroll_box.html', data)
 
 @register.simple_tag(name='infinite_scroll_tags', takes_context=True)
@@ -24,6 +24,14 @@ def infinite_scroll_tags(context):
     """ renders the html that loads the dynamic content.
     This is used by {% infinite_scroll_box %} tag.
     """
-    data = context.dicts[-1]
+    data = get_context_data(context)
     return render_to_string('infscroll/scroll_tags.html', data)
 
+
+def get_context_data(context):
+    """ Get the correct dictionary from the context.
+    Maybe there is a better way to do this...
+    """
+    for ctx_dict in context.dicts:
+        if 'feed' in ctx_dict.keys():
+            return ctx_dict
